<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dist?lang_cible=ja
// ** ne pas modifier le fichier **

return [

	// D
	'dist_description' => 'SPIP 3で配布されたテンプレートセットです。',
	'dist_slogan' => 'SPIP 3用のデフォルトテンプレートです。',
];
